@@ -16,6 +16,18 @@ struct LevenshteinWeightTable {
     size_t replace_cost;
 };
 
+static inline size_t levenshtein_maximum(size_t len1, size_t len2, LevenshteinWeightTable weights)
+{
+    size_t max_dist = len1 * weights.delete_cost + len2 * weights.insert_cost;
+
+    if (len1 >= len2)
+        max_dist = std::min(max_dist, len2 * weights.replace_cost + (len1 - len2) * weights.delete_cost);
+    else
+        max_dist = std::min(max_dist, len1 * weights.replace_cost + (len2 - len1) * weights.insert_cost);
+
+    return max_dist;
+}
+
 template <typename InputIt1, typename InputIt2>
 Matrix<size_t> levenshtein_matrix(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
                                   LevenshteinWeightTable weights = {1, 1, 1})
@@ -69,4 +81,24 @@ size_t levenshtein_distance(const Sentence1& s1, const Sentence2& s2,
                                 score_cutoff);
 }
 
+template <typename InputIt1, typename InputIt2>
+double levenshtein_similarity(InputIt1 first1, InputIt1 last1, InputIt2 first2, InputIt2 last2,
+                              LevenshteinWeightTable weights = {1, 1, 1}, double score_cutoff = 0.0)
+{
+    size_t len1 = static_cast<size_t>(std::distance(first1, last1));
+    size_t len2 = static_cast<size_t>(std::distance(first2, last2));
+    size_t dist = levenshtein_distance(first1, last1, first2, last2, weights);
+    size_t max = levenshtein_maximum(len1, len2, weights);
+    double sim = 1.0 - (double)dist / max;
+    return (sim >= score_cutoff) ? sim : 0.0;
+}
+
+template <typename Sentence1, typename Sentence2>
+double levenshtein_similarity(const Sentence1& s1, const Sentence2& s2,
+                              LevenshteinWeightTable weights = {1, 1, 1}, double score_cutoff = 0.0)
+{
+    return levenshtein_similarity(std::begin(s1), std::end(s1), std::begin(s2), std::end(s2), weights,
+                                  score_cutoff);
+}
+
 } // namespace rapidfuzz_reference
