@@ -1,11 +1,16 @@
+#if CATCH2_VERSION == 2
+#    include <catch2/catch.hpp>
+#else
+#    include <catch2/catch_test_macros.hpp>
+#    include <catch2/matchers/catch_matchers_floating_point.hpp>
+#endif
+
 #include "../../rapidfuzz_reference/Jaro.hpp"
-#include <catch2/catch_approx.hpp>
-#include <catch2/catch_test_macros.hpp>
 #include <rapidfuzz/distance/Jaro.hpp>
 
 #include "../common.hpp"
 
-using Catch::Approx;
+using Catch::Matchers::WithinAbs;
 
 template <typename Sentence1, typename Sentence2>
 double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cutoff = 0.0)
@@ -17,10 +22,10 @@ double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cu
         rapidfuzz::jaro_normalized_similarity(s1.begin(), s1.end(), s2.begin(), s2.end(), score_cutoff);
 #if 0 // todo
     double res5 = rapidfuzz::jaro_similarity(
-        BidirectionalIterWrapper(s1.begin()), BidirectionalIterWrapper(s1.end()),
-        BidirectionalIterWrapper(s2.begin()), BidirectionalIterWrapper(s2.end()), score_cutoff);
+        make_bidir(s1.begin()), make_bidir(s1.end()),
+        make_bidir(s2.begin()), make_bidir(s2.end()), score_cutoff);
 #endif
-    rapidfuzz::CachedJaro scorer(s1);
+    rapidfuzz::CachedJaro<rapidfuzz::char_type<Sentence1>> scorer(s1);
     double res6 = scorer.similarity(s2, score_cutoff);
     double res7 = scorer.similarity(s2.begin(), s2.end(), score_cutoff);
     double res8 = scorer.normalized_similarity(s2, score_cutoff);
@@ -35,7 +40,7 @@ double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cu
 
         simd_scorer.similarity(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 32; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 16) {
         rapidfuzz::experimental::MultiJaro<16> simd_scorer(16);
@@ -44,7 +49,7 @@ double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cu
 
         simd_scorer.similarity(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 16; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 32) {
         rapidfuzz::experimental::MultiJaro<32> simd_scorer(8);
@@ -53,7 +58,7 @@ double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cu
 
         simd_scorer.similarity(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 8; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 64) {
         rapidfuzz::experimental::MultiJaro<64> simd_scorer(4);
@@ -62,18 +67,18 @@ double jaro_similarity(const Sentence1& s1, const Sentence2& s2, double score_cu
 
         simd_scorer.similarity(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 4; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
 #endif
 
-    REQUIRE(res1 == Approx(res2));
-    REQUIRE(res1 == Approx(res3));
-    REQUIRE(res1 == Approx(res4));
-    // REQUIRE(res1 == Approx(res5));
-    REQUIRE(res1 == Approx(res6));
-    REQUIRE(res1 == Approx(res7));
-    REQUIRE(res1 == Approx(res8));
-    REQUIRE(res1 == Approx(res9));
+    REQUIRE_THAT(res1, WithinAbs(res2, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res3, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res4, 0.000001));
+    // REQUIRE_THAT(res1, WithinAbs(res5, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res6, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res7, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res8, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res9, 0.000001));
     return res1;
 }
 
@@ -87,10 +92,10 @@ double jaro_distance(const Sentence1& s1, const Sentence2& s2, double score_cuto
         rapidfuzz::jaro_normalized_distance(s1.begin(), s1.end(), s2.begin(), s2.end(), score_cutoff);
 #if 0 // todo
     double res5 = rapidfuzz::jaro_distance(
-        BidirectionalIterWrapper(s1.begin()), BidirectionalIterWrapper(s1.end()),
-        BidirectionalIterWrapper(s2.begin()), BidirectionalIterWrapper(s2.end()), score_cutoff);
+        make_bidir(s1.begin()), make_bidir(s1.end()),
+        make_bidir(s2.begin()), make_bidir(s2.end()), score_cutoff);
 #endif
-    rapidfuzz::CachedJaro scorer(s1);
+    rapidfuzz::CachedJaro<rapidfuzz::char_type<Sentence1>> scorer(s1);
     double res6 = scorer.distance(s2, score_cutoff);
     double res7 = scorer.distance(s2.begin(), s2.end(), score_cutoff);
     double res8 = scorer.normalized_distance(s2, score_cutoff);
@@ -105,7 +110,7 @@ double jaro_distance(const Sentence1& s1, const Sentence2& s2, double score_cuto
 
         simd_scorer.distance(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 32; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 16) {
         rapidfuzz::experimental::MultiJaro<16> simd_scorer(16);
@@ -114,7 +119,7 @@ double jaro_distance(const Sentence1& s1, const Sentence2& s2, double score_cuto
 
         simd_scorer.distance(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 16; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 32) {
         rapidfuzz::experimental::MultiJaro<32> simd_scorer(8);
@@ -123,7 +128,7 @@ double jaro_distance(const Sentence1& s1, const Sentence2& s2, double score_cuto
 
         simd_scorer.distance(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 8; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
     if (s1.size() <= 64) {
         rapidfuzz::experimental::MultiJaro<64> simd_scorer(4);
@@ -132,18 +137,18 @@ double jaro_distance(const Sentence1& s1, const Sentence2& s2, double score_cuto
 
         simd_scorer.distance(&results[0], results.size(), s2, score_cutoff);
         for (size_t i = 0; i < 4; ++i)
-            REQUIRE(res1 == Approx(results[i]));
+            REQUIRE_THAT(res1, WithinAbs(results[i], 0.000001));
     }
 #endif
 
-    REQUIRE(res1 == Approx(res2));
-    REQUIRE(res1 == Approx(res3));
-    REQUIRE(res1 == Approx(res4));
-    // REQUIRE(res1 == Approx(res5));
-    REQUIRE(res1 == Approx(res6));
-    REQUIRE(res1 == Approx(res7));
-    REQUIRE(res1 == Approx(res8));
-    REQUIRE(res1 == Approx(res9));
+    REQUIRE_THAT(res1, WithinAbs(res2, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res3, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res4, 0.000001));
+    // REQUIRE_THAT(res1, WithinAbs(res5, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res6, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res7, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res8, 0.000001));
+    REQUIRE_THAT(res1, WithinAbs(res9, 0.000001));
     return res1;
 }
 
@@ -157,10 +162,10 @@ double jaro_sim_test(const Sentence1& s1, const Sentence2& s2, double score_cuto
     double Sim_bitparallel2 = jaro_similarity(s2, s1, score_cutoff);
     double Dist_bitparallel2 = jaro_distance(s2, s1, 1.0 - score_cutoff);
 
-    REQUIRE(Sim_original == Approx(Sim_bitparallel));
-    REQUIRE((1.0 - Sim_original) == Approx(Dist_bitparallel));
-    REQUIRE(Sim_original == Approx(Sim_bitparallel2));
-    REQUIRE((1.0 - Sim_original) == Approx(Dist_bitparallel2));
+    REQUIRE_THAT(Sim_original, WithinAbs(Sim_bitparallel, 0.000001));
+    REQUIRE_THAT((1.0 - Sim_original), WithinAbs(Dist_bitparallel, 0.000001));
+    REQUIRE_THAT(Sim_original, WithinAbs(Sim_bitparallel2, 0.000001));
+    REQUIRE_THAT((1.0 - Sim_original), WithinAbs(Dist_bitparallel2, 0.000001));
     return Sim_original;
 }
 
@@ -183,43 +188,46 @@ TEST_CASE("JaroTest")
 
     SECTION("testEdgeCaseLengths")
     {
-        REQUIRE(jaro_sim_test(std::string(""), std::string("")) == Approx(1));
-        REQUIRE(jaro_sim_test(std::string("0"), std::string("0")) == Approx(1));
-        REQUIRE(jaro_sim_test(std::string("00"), std::string("00")) == Approx(1));
-        REQUIRE(jaro_sim_test(std::string("0"), std::string("00")) == Approx(0.833333));
+        REQUIRE_THAT(jaro_sim_test(std::string(""), std::string("")), WithinAbs(1, 0.000001));
+        REQUIRE_THAT(jaro_sim_test(std::string("0"), std::string("0")), WithinAbs(1, 0.000001));
+        REQUIRE_THAT(jaro_sim_test(std::string("00"), std::string("00")), WithinAbs(1, 0.000001));
+        REQUIRE_THAT(jaro_sim_test(std::string("0"), std::string("00")), WithinAbs(0.833333, 0.000001));
 
-        REQUIRE(jaro_sim_test(str_multiply(std::string("0"), 65), str_multiply(std::string("0"), 65)) ==
-                Approx(1));
-        REQUIRE(jaro_sim_test(str_multiply(std::string("0"), 64), str_multiply(std::string("0"), 65)) ==
-                Approx(0.994872));
-        REQUIRE(jaro_sim_test(str_multiply(std::string("0"), 63), str_multiply(std::string("0"), 65)) ==
-                Approx(0.989744));
+        REQUIRE_THAT(jaro_sim_test(str_multiply(std::string("0"), 65), str_multiply(std::string("0"), 65)),
+                     WithinAbs(1, 0.000001));
+        REQUIRE_THAT(jaro_sim_test(str_multiply(std::string("0"), 64), str_multiply(std::string("0"), 65)),
+                     WithinAbs(0.994872, 0.000001));
+        REQUIRE_THAT(jaro_sim_test(str_multiply(std::string("0"), 63), str_multiply(std::string("0"), 65)),
+                     WithinAbs(0.989744, 0.000001));
 
-        REQUIRE(jaro_sim_test(std::string("000000001"), std::string("0000010")) == Approx(0.8783068783));
+        REQUIRE_THAT(jaro_sim_test(std::string("000000001"), std::string("0000010")),
+                     WithinAbs(0.8783068783, 0.000001));
         {
             std::string s1("01234567");
             std::string s2 = str_multiply(std::string("0"), 170) + std::string("7654321") +
                              str_multiply(std::string("0"), 200);
 
-            REQUIRE(jaro_sim_test(s1, s2) == Approx(0.5487400531));
+            REQUIRE_THAT(jaro_sim_test(s1, s2), WithinAbs(0.5487400531, 0.000001));
         }
 
-        REQUIRE(jaro_sim_test(std::string("01"), std::string("1111100000")) == Approx(0.53333333));
+        REQUIRE_THAT(jaro_sim_test(std::string("01"), std::string("1111100000")),
+                     WithinAbs(0.53333333, 0.000001));
 
-        REQUIRE(
+        REQUIRE_THAT(
             jaro_sim_test(std::string("10000000000000000000000000000000000000000000000000000000000000020"),
-                          std::string("00000000000000000000000000000000000000000000000000000000000000000")) ==
-            Approx(0.979487));
-        REQUIRE(jaro_sim_test(
-                    std::string("00000000000000100000000000000000000000010000000000000000000000000"),
-                    std::string(
-                        "0000000000000000000000000000000000000000000000000000000000000000000000000000001")) ==
-                Approx(0.922233));
-        REQUIRE(
+                          std::string("00000000000000000000000000000000000000000000000000000000000000000")),
+            WithinAbs(0.979487, 0.000001));
+        REQUIRE_THAT(
+            jaro_sim_test(
+                std::string("00000000000000100000000000000000000000010000000000000000000000000"),
+                std::string(
+                    "0000000000000000000000000000000000000000000000000000000000000000000000000000001")),
+            WithinAbs(0.922233, 0.000001));
+        REQUIRE_THAT(
             jaro_sim_test(std::string("00000000000000000000000000000000000000000000000000000000000000000"),
                           std::string("0100000000000000000000000000000000000000000000000000000000000000000000"
-                                      "0000000000000000000000000000000000000000000000000000000000")) ==
-            Approx(0.8359375));
+                                      "0000000000000000000000000000000000000000000000000000000000")),
+            WithinAbs(0.8359375, 0.000001));
     }
 
     SECTION("testFuzzingRegressions")
@@ -240,9 +248,9 @@ TEST_CASE("JaroTest")
             simd_scorer.similarity(&results[0], results.size(), s2);
 
             for (size_t i = 0; i < 32; ++i)
-                REQUIRE(results[i] == Approx(0.593750));
+                REQUIRE_THAT(results[i], WithinAbs(0.593750, 0.000001));
 
-            REQUIRE(results[32] == Approx(0.593750));
+            REQUIRE_THAT(results[32], WithinAbs(0.593750, 0.000001));
         }
 #endif
     }
